@@ -1,52 +1,38 @@
 /*  This file is part of the KDE libraries
- *  Copyright 2013 Kevin Ottens <ervin+bluesystems@kde.org>
- *  Copyright 2013 Aleix Pol Gonzalez <aleixpol@blue-systems.com>
- *  Copyright 2014 Lukáš Tinkl <ltinkl@redhat.com>
- *
- *  This library is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU Lesser General Public License as published by
- *  the Free Software Foundation; either version 2 of the License or ( at
- *  your option ) version 3 or, at the discretion of KDE e.V. ( which shall
- *  act as a proxy as in section 14 of the GPLv3 ), any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Lesser General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- */
+    SPDX-FileCopyrightText: 2013 Kevin Ottens <ervin+bluesystems@kde.org>
+    SPDX-FileCopyrightText: 2013 Aleix Pol Gonzalez <aleixpol@blue-systems.com>
+    SPDX-FileCopyrightText: 2014 Lukáš Tinkl <ltinkl@redhat.com>
+
+    SPDX-License-Identifier: LGPL-2.0-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+*/
 
 #include <config-platformtheme.h>
 
+#include "kdeplatformfiledialoghelper.h"
+#include "kdeplatformsystemtrayicon.h"
 #include "kdeplatformtheme.h"
 #include "kfontsettingsdata.h"
 #include "khintssettings.h"
-#include "kdeplatformfiledialoghelper.h"
-#include "kdeplatformsystemtrayicon.h"
 #include "kwaylandintegration.h"
 #include "x11integration.h"
 
 #include <QApplication>
+#include <QDBusConnection>
+#include <QDBusConnectionInterface>
+#include <QDebug>
 #include <QFont>
 #include <QPalette>
 #include <QString>
 #include <QVariant>
-#include <QDBusConnection>
-#include <QDBusConnectionInterface>
-#include <QDebug>
 #include <QtQuickControls2/QQuickStyle>
 
+#include <KIO/Global>
+#include <KLocalizedString>
+#include <KStandardGuiItem>
+#include <KWindowSystem>
 #include <kiconengine.h>
 #include <kiconloader.h>
 #include <kstandardshortcut.h>
-#include <KStandardGuiItem>
-#include <KLocalizedString>
-#include <KWindowSystem>
-#include <KIO/Global>
 
 #include "qdbusmenubar_p.h"
 #include "qxdgdesktopportalfiledialog_p.h"
@@ -87,6 +73,14 @@ KdePlatformTheme::KdePlatformTheme()
     }
 #endif
 
+    // Don't show the titlebar "What's This?" help button for dialogs that
+    // have any UI elements with help text, unless the window specifically
+    // requests it. This is because KDE apps with help text will use the nice
+    // contextual tooltips instead; we only want to ever see the titlebar button
+    // to invoke the "What's This?" feature in 3rd-party Qt apps that have set
+    // "What's This" help text and requested the button
+    QCoreApplication::setAttribute(Qt::AA_DisableWindowContextHelpButton, true);
+
     QCoreApplication::setAttribute(Qt::AA_DontUseNativeMenuBar, false);
     setQtQuickControlsTheme();
 }
@@ -131,11 +125,13 @@ const QFont *KdePlatformTheme::font(Font type) const
     KFontSettingsData::FontTypes fdtype;
     switch (type) {
     case SystemFont:
-        fdtype = KFontSettingsData::GeneralFont; break;
+        fdtype = KFontSettingsData::GeneralFont;
+        break;
     case MenuFont:
     case MenuBarFont:
     case MenuItemFont:
-        fdtype = KFontSettingsData::MenuFont; break;
+        fdtype = KFontSettingsData::MenuFont;
+        break;
     case MessageBoxFont:
     case LabelFont:
     case TipLabelFont:
@@ -147,20 +143,26 @@ const QFont *KdePlatformTheme::font(Font type) const
     case ListBoxFont:
     case ComboMenuItemFont:
     case ComboLineEditFont:
-        fdtype = KFontSettingsData::GeneralFont; break;
+        fdtype = KFontSettingsData::GeneralFont;
+        break;
     case TitleBarFont:
     case MdiSubWindowTitleFont:
     case DockWidgetTitleFont:
-        fdtype = KFontSettingsData::WindowTitleFont; break;
+        fdtype = KFontSettingsData::WindowTitleFont;
+        break;
     case SmallFont:
     case MiniFont:
-        fdtype = KFontSettingsData::SmallestReadableFont; break;
+        fdtype = KFontSettingsData::SmallestReadableFont;
+        break;
     case FixedFont:
-        fdtype = KFontSettingsData::FixedFont; break;
+        fdtype = KFontSettingsData::FixedFont;
+        break;
     case ToolButtonFont:
-        fdtype = KFontSettingsData::ToolbarFont; break;
+        fdtype = KFontSettingsData::ToolbarFont;
+        break;
     default:
-        fdtype = KFontSettingsData::GeneralFont; break;
+        fdtype = KFontSettingsData::GeneralFont;
+        break;
     }
 
     return m_fontsData->font(fdtype);
@@ -267,7 +269,7 @@ QList<QKeySequence> KdePlatformTheme::keyBindings(QKeySequence::StandardKey key)
 
 bool KdePlatformTheme::usePlatformNativeDialog(QPlatformTheme::DialogType type) const
 {
-    return type == QPlatformTheme::FileDialog && qobject_cast<QApplication*>(QCoreApplication::instance());
+    return type == QPlatformTheme::FileDialog && qobject_cast<QApplication *>(QCoreApplication::instance());
 }
 
 QString KdePlatformTheme::standardButtonText(int button) const
@@ -377,18 +379,18 @@ QPlatformMenuBar *KdePlatformTheme::createPlatformMenuBar() const
     return nullptr;
 }
 
-//force QtQuickControls2 to use the desktop theme as default
+// force QtQuickControls2 to use the desktop theme as default
 void KdePlatformTheme::setQtQuickControlsTheme()
 {
-    //if the user is running only a QGuiApplication, explicitly unset the QQC1 desktop style and abort
-    //as this style is all about QWidgets and we know setting this will make it crash
-    if (!qobject_cast<QApplication*>(qApp)) {
+    // if the user is running only a QGuiApplication, explicitly unset the QQC1 desktop style and abort
+    // as this style is all about QWidgets and we know setting this will make it crash
+    if (!qobject_cast<QApplication *>(qApp)) {
         if (qgetenv("QT_QUICK_CONTROLS_1_STYLE").right(7) == "Desktop") {
             qunsetenv("QT_QUICK_CONTROLS_1_STYLE");
         }
         return;
     }
-    //if the user has explicitly set something else, don't meddle
+    // if the user has explicitly set something else, don't meddle
     if (!QQuickStyle::name().isEmpty()) {
         return;
     }
